@@ -13,9 +13,19 @@ import io
 import argparse
 import json
 import os
+import mlflow
+
+
+def GetAzureMLRun():
+    try:
+        run = Run.get_context()
+    except:
+        return None
+    
+    return run
 
 def RegisterModel(model_path, description, args):
-    run = Run.get_context()
+    run = GetAzureMLRun()
 
     if run:
         experiment = Run.get_context(allow_offline=False).experiment
@@ -30,9 +40,18 @@ def RegisterModel(model_path, description, args):
                         'deploymentName': args.deploymentName, 
                         'apiVersion':args.apiVersion,
                         'subscriptionId':args.subscriptionId})
+    else:
+        mlFlowRun = mlflow.active_run()
+        if mlFlowRun:
+            model_uri = "runs:/{run_id}/{artifact_path}".format(run_id=mlFlowRun.info.run_id, artifact_path=model_path)
+            result = mlflow.register_model(
+                model_uri,
+                args.modelId
+            )
+
     
 def DownloadModel(model_id, model_path):
-    run = Run.get_context()
+    run = GetAzureMLRun()
     if run:
         experiment = Run.get_context(allow_offline=False).experiment
         ws = experiment.workspace
@@ -107,9 +126,7 @@ def DeployModel():
     endpoint_id = args.endpointId
 
     print(dns_name_label)
-
-
-    run = Run.get_context()
+    run = GetAzureMLRun()
 
     ## If it is running in AML context
     if run:
